@@ -1022,6 +1022,9 @@ private:
 
     KMessageWidget *_readOnlyMessageWidget; // Message shown at the top when read-only mode gets activated
 
+    // Needed to know whether the mode really changed between update calls
+    bool _readOnly;
+
     qreal _opacity;
 
     ScrollState _scrollWheelState;
