@@ -30,39 +30,39 @@
 using namespace Konsole;
 
 const ColorEntry CharacterColorTest::DefaultColorTable[TABLE_COLORS] = {
-    ColorEntry(QColor(0x00, 0x00, 0x00)), // Dfore
-    ColorEntry(QColor(0xFF, 0xFF, 0xFF)), // Dback
-    ColorEntry(QColor(0x00, 0x00, 0x00)), // Black
-    ColorEntry(QColor(0xB2, 0x18, 0x18)), // Red
-    ColorEntry(QColor(0x18, 0xB2, 0x18)), // Green
-    ColorEntry(QColor(0xB2, 0x68, 0x18)), // Yellow
-    ColorEntry(QColor(0x18, 0x18, 0xB2)), // Blue
-    ColorEntry(QColor(0xB2, 0x18, 0xB2)), // Magenta
-    ColorEntry(QColor(0x18, 0xB2, 0xB2)), // Cyan
-    ColorEntry(QColor(0xB2, 0xB2, 0xB2)), // White
+    ColorEntry(0x00, 0x00, 0x00), // Dfore
+    ColorEntry(0xFF, 0xFF, 0xFF), // Dback
+    ColorEntry(0x00, 0x00, 0x00), // Black
+    ColorEntry(0xB2, 0x18, 0x18), // Red
+    ColorEntry(0x18, 0xB2, 0x18), // Green
+    ColorEntry(0xB2, 0x68, 0x18), // Yellow
+    ColorEntry(0x18, 0x18, 0xB2), // Blue
+    ColorEntry(0xB2, 0x18, 0xB2), // Magenta
+    ColorEntry(0x18, 0xB2, 0xB2), // Cyan
+    ColorEntry(0xB2, 0xB2, 0xB2), // White
     // intensive versions
-    ColorEntry(QColor(0x00, 0x00, 0x00)),
-    ColorEntry(QColor(0xFF, 0xFF, 0xFF)),
-    ColorEntry(QColor(0x68, 0x68, 0x68)),
-    ColorEntry(QColor(0xFF, 0x54, 0x54)),
-    ColorEntry(QColor(0x54, 0xFF, 0x54)),
-    ColorEntry(QColor(0xFF, 0xFF, 0x54)),
-    ColorEntry(QColor(0x54, 0x54, 0xFF)),
-    ColorEntry(QColor(0xFF, 0x54, 0xFF)),
-    ColorEntry(QColor(0x54, 0xFF, 0xFF)),
-    ColorEntry(QColor(0xFF, 0xFF, 0xFF)),
+    ColorEntry(0x00, 0x00, 0x00),
+    ColorEntry(0xFF, 0xFF, 0xFF),
+    ColorEntry(0x68, 0x68, 0x68),
+    ColorEntry(0xFF, 0x54, 0x54),
+    ColorEntry(0x54, 0xFF, 0x54),
+    ColorEntry(0xFF, 0xFF, 0x54),
+    ColorEntry(0x54, 0x54, 0xFF),
+    ColorEntry(0xFF, 0x54, 0xFF),
+    ColorEntry(0x54, 0xFF, 0xFF),
+    ColorEntry(0xFF, 0xFF, 0xFF),
     // Here are faint intensities, which may not be good.
     // faint versions
-    ColorEntry(QColor(0x00, 0x00, 0x00)),
-    ColorEntry(QColor(0xFF, 0xFF, 0xFF)),
-    ColorEntry(QColor(0x00, 0x00, 0x00)),
-    ColorEntry(QColor(0x65, 0x00, 0x00)),
-    ColorEntry(QColor(0x00, 0x65, 0x00)),
-    ColorEntry(QColor(0x65, 0x5E, 0x00)),
-    ColorEntry(QColor(0x00, 0x00, 0x65)),
-    ColorEntry(QColor(0x65, 0x00, 0x65)),
-    ColorEntry(QColor(0x00, 0x65, 0x65)),
-    ColorEntry(QColor(0x65, 0x65, 0x65))
+    ColorEntry(0x00, 0x00, 0x00),
+    ColorEntry(0xFF, 0xFF, 0xFF),
+    ColorEntry(0x00, 0x00, 0x00),
+    ColorEntry(0x65, 0x00, 0x00),
+    ColorEntry(0x00, 0x65, 0x00),
+    ColorEntry(0x65, 0x5E, 0x00),
+    ColorEntry(0x00, 0x00, 0x65),
+    ColorEntry(0x65, 0x00, 0x65),
+    ColorEntry(0x00, 0x65, 0x65),
+    ColorEntry(0x65, 0x65, 0x65)
 };
 
 void CharacterColorTest::init()
@@ -75,10 +75,10 @@ void CharacterColorTest::cleanup()
 
 void CharacterColorTest::testColorEntry()
 {
-    ColorEntry black = ColorEntry(QColor(0x00, 0x00, 0x00));
-    ColorEntry white = ColorEntry(QColor(0xFF, 0xFF, 0xFF));
-    ColorEntry red   = ColorEntry(QColor(0xB2, 0x18, 0x18));
-    ColorEntry green = ColorEntry(QColor(0x18, 0xB2, 0x18));
+    ColorEntry black = ColorEntry(0x00, 0x00, 0x00);
+    ColorEntry white = ColorEntry(0xFF, 0xFF, 0xFF);
+    ColorEntry red   = ColorEntry(0xB2, 0x18, 0x18);
+    ColorEntry green = ColorEntry(0x18, 0xB2, 0x18);
 
     // Test operator== operator!=
     QCOMPARE(black == white, false);
@@ -100,7 +100,6 @@ void CharacterColorTest::testColorEntry()
     QCOMPARE(defaultColorEntry != green, true);
     QCOMPARE(defaultColorEntry != black, true);
     QCOMPARE(defaultColorEntry.isValid(), false);
-
 }
 
 void CharacterColorTest::testDummyConstructor()
@@ -156,4 +155,3 @@ void CharacterColorTest::testColorSpaceSystem()
 }
 
 QTEST_GUILESS_MAIN(CharacterColorTest)
-
