@@ -22,7 +22,7 @@
 
 // Qt
 #include <QStyledItemDelegate>
-#include <QtCore/QSet>
+#include <QSet>
 
 // KDE
 
@@ -35,8 +35,7 @@ class QShowEvent;
 class QStandardItem;
 class QStandardItemModel;
 
-namespace Konsole
-{
+namespace Konsole {
 /**
  * A dialog which lists the available types of profiles and allows
  * the user to add new profiles, and remove or edit existing
@@ -51,8 +50,8 @@ class ProfileSettings : public QWidget, private Ui::ProfileSettings
 
 public:
     /** Constructs a new profile type with the specified parent. */
-    explicit ProfileSettings(QWidget* parent = 0);
-    virtual ~ProfileSettings();
+    explicit ProfileSettings(QWidget *parent = nullptr);
+    ~ProfileSettings() Q_DECL_OVERRIDE;
 
     /**
      * Specifies whether the shortcut editor should be show.
@@ -66,9 +65,8 @@ public:
     void setShortcutEditorVisible(bool visible);
 
 protected:
-    virtual void showEvent(QShowEvent* event);
 
-private slots:
+private Q_SLOTS:
     void slotAccepted();
     void deleteSelected();
     void setSelectedAsDefault();
@@ -77,11 +75,11 @@ private slots:
     void moveUpSelected();
     void moveDownSelected();
 
-    void itemDataChanged(QStandardItem* item);
+    void itemDataChanged(QStandardItem *item);
 
     // enables or disables Edit/Delete/Set as Default buttons when the
     // selection changes
-    void tableSelectionChanged(const QItemSelection&);
+    void tableSelectionChanged(const QItemSelection &);
 
     void updateFavoriteStatus(Profile::Ptr profile, bool favorite);
 
@@ -89,6 +87,9 @@ private slots:
     void updateItems(const Profile::Ptr);
     void removeItems(const Profile::Ptr);
 
+    // double clicking the profile name opens the edit profile dialog
+    void doubleClicked(const QModelIndex &index);
+
 private:
     Profile::Ptr currentProfile() const;
     QList<Profile::Ptr> selectedProfiles() const;
@@ -97,13 +98,13 @@ private:
     // updates the font of the items to match
     // their default / non-default profile status
     void updateDefaultItem();
-    void updateItemsForProfile(const Profile::Ptr profile, QList<QStandardItem*>& items) const;
+    void updateItemsForProfile(const Profile::Ptr profile, QList<QStandardItem *> &items) const;
     // updates the profile table to be in sync with the
     // session manager
     void populateTable();
     int rowForProfile(const Profile::Ptr profile) const;
 
-    QStandardItemModel* _sessionModel;
+    QStandardItemModel *_sessionModel;
 
     static const int ProfileNameColumn = 0;
     static const int FavoriteStatusColumn = 1;
@@ -115,8 +116,8 @@ private:
 class StyledBackgroundPainter
 {
 public:
-    static void drawBackground(QPainter* painter, const QStyleOptionViewItem& option,
-                               const QModelIndex& index);
+    static void drawBackground(QPainter *painter, const QStyleOptionViewItem &option,
+                               const QModelIndex &index);
 };
 
 class FavoriteItemDelegate : public QStyledItemDelegate
@@ -124,12 +125,12 @@ class FavoriteItemDelegate : public QStyledItemDelegate
     Q_OBJECT
 
 public:
-    explicit FavoriteItemDelegate(QObject* parent = 0);
+    explicit FavoriteItemDelegate(QObject *parent = nullptr);
 
-    virtual bool editorEvent(QEvent* event, QAbstractItemModel* model,
-                             const QStyleOptionViewItem& option, const QModelIndex& index);
-    virtual void paint(QPainter* painter, const QStyleOptionViewItem& option,
-                       const QModelIndex& index) const;
+    bool editorEvent(QEvent *event, QAbstractItemModel *model, const QStyleOptionViewItem &option,
+                     const QModelIndex &index) Q_DECL_OVERRIDE;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option,
+               const QModelIndex &index) const Q_DECL_OVERRIDE;
 };
 
 class ShortcutItemDelegate : public QStyledItemDelegate
@@ -137,21 +138,21 @@ class ShortcutItemDelegate : public QStyledItemDelegate
     Q_OBJECT
 
 public:
-    explicit ShortcutItemDelegate(QObject* parent = 0);
+    explicit ShortcutItemDelegate(QObject *parent = nullptr);
 
-    virtual void setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const;
-    virtual QWidget* createEditor(QWidget* parent, const QStyleOptionViewItem& option,
-                                  const QModelIndex& index) const;
-    virtual void paint(QPainter* painter, const QStyleOptionViewItem& option,
-                       const QModelIndex& index) const;
+    void setModelData(QWidget *editor, QAbstractItemModel *model,
+                      const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
+                          const QModelIndex &index) const Q_DECL_OVERRIDE;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option,
+               const QModelIndex &index) const Q_DECL_OVERRIDE;
 
-private slots:
-    void editorModified(const QKeySequence& keys);
+private Q_SLOTS:
+    void editorModified(const QKeySequence &keys);
 
 private:
-    mutable QSet<QWidget*> _modifiedEditors;
+    mutable QSet<QWidget *> _modifiedEditors;
     mutable QSet<QModelIndex> _itemsBeingEdited;
 };
 }
 #endif // MANAGEPROFILESDIALOG_H
-
